package matrices;

import java.awt.*;

public class LineUtil {
    private LineUtil() {
    }

    /**
     * Tworzy obiekt typu Line z równania linii,
     * jeśli równanie linii wyrażone jest w postaci aX + bY + c;
     *
     * @param a double - współczynnik a równania linii;
     * @param b double - współczynnik b równania linii
     * @param c double - współczynnik c równania linii
     * @return Line - obiekt linii wyrażonej równaniem o podanych
     * współczynnikach
     */
    public static Line findLine(double a, double b, double c) {
        double x1 = 0;
        double x2 = 3;
        if (b != 0) {
            double y1 = -c / b - a / b * x1;
            double y2 = -c / b - a / b * x2;
            return new Line(x1, y1, x2, y2);
        } else {
            throw new IllegalArgumentException("b nie może być równe 0");
        }
    }

    public static void drawLine(Line line, Graphics2D g2, Color color,
                                double percent) {
        float x0 = 800f;
        float y0 = 800f;
        float x1 = (float) line.getStart().getX();
        float y1 = (float) line.getStart().getY();
        float x2 = (float) line.getEnd().getX();
        float y2 = (float) line.getEnd().getY();
        Line line1 = new Line(x0 / 2f + x1 * 30f, (y0 - 30f) / 2f - y1 * 30f,
                x0 / 2f + x2 * 30f, (y0 - 30f) / 2f - y2 * 30f);
        Line line2 = LineUtil.prolongate(line1, percent);
        g2.setColor(color);
        g2.draw(line2);
        g2.setColor(Color.BLACK);
    }

    public static Line prolongate(Line line, double percent) {
        double prol = line.getLength() * percent / 100.0;
        double endx = line.getEnd().getX() + prol * line.getCosinus();
        double endy = line.getEnd().getY() + prol * line.getSinus();
        double startx = line.getStart().getX() - prol * line.getCosinus();
        double starty = line.getStart().getY() - prol * line.getSinus();
        return new Line(startx, starty, endx, endy);
    }

}
